# playbook-checker

Script to check playbooks and provide report

# Setup

~~~~
cd
git clone https://github.com/vengaar/playbook-checker.git
cd playbook-checker
git checkout devel
sudo pip3 install . -v
playbook_checker --path tests/
~~~~
